==> anymeal_0.29-3.orig.tar.gz: anymeal-0.29/anymeal.mm <==
<map version="0.7.1">
<node TEXT="anymeal">
<node COLOR="#bfbfbf" TEXT="backup/restore for database" POSITION="left"/>
<node TEXT="Axis C++ Server/XQuery" FOLDED="true" POSITION="right">
<node TEXT="XSD for protocol (wrapping of anymeal.xsd?)"/>
</node>
<node COLOR="#ff0000" TEXT="Proper log-window for database server" POSITION="left"/>
<node TEXT="Reconnect button (problem with temporary table)" POSITION="right"/>
<node COLOR="#ff0000" TEXT="* Umstellung auf Qt4&#xa;* Closed-source release ohne KDE, Nsis, Windows port&#xa;" POSITION="right">
<node TEXT="KDE IO-slave">
<node TEXT="Import from web-pages:&#xa;epicurious, allrecipes.com, and recipezaar.com"/>
<node TEXT="RecipeML import from archives"/>
<node TEXT="Import von Newsgruppen"/>
</node>
<node TEXT="Multiple selections">
<node TEXT="Provide &quot;Last Imported&quot; as selection (comp. Refworks),&#xa;Zeige Zahl der importierten Rezepte an">
<node TEXT="provide statistic on selections"/>
</node>
<node TEXT="expert mode for performing searches">
<node TEXT="Speed up search. Distinguish&#xa;* regular expression/word&#xa;* substring&#xa;* fulltext/word&#xa;Allow clear search"/>
</node>
</node>
<node TEXT="Vorw&#xe4;rts-/R&#xfc;ckw&#xe4;rts-Button"/>
<node TEXT="Smart shopping list planner"/>
<node TEXT="online context help"/>
<node TEXT="display recipe-ID in editor caption"/>
<node TEXT="faster recipe display/browsing through recipes"/>
<node TEXT="Editing copy of recipe"/>
<node COLOR="#ff0000" TEXT="Verification of editor"/>
<node TEXT="colourful user-interface"/>
<node TEXT="sort by most frequently used, rating for recipes"/>
<node TEXT="combining search queries (f.e. category &quot;Indian&quot; and &quot;Dessert&quot;)"/>
<node TEXT="direct printing out of recipes"/>
<node TEXT="sort recipes by category or title"/>
<node COLOR="#bfbfbf" TEXT="KDE clipboard"/>
</node>
<node TEXT="MySQL &lt;-&gt; XML http://dev.mysql.com/tech-resources/articles/mysql-5.1-xml.html&#xa;http://en.wikipedia.org/wiki/MySQL&#xa;http://en.wikipedia.org/wiki/PostgreSQL" POSITION="right"/>
<node TEXT="Add filename information to mealmaster-error (both for abort on error and export erroneous files), when importing" POSITION="right"/>
<node TEXT="Allow exporting not only with context-menu." POSITION="right"/>
<node TEXT="Internationalisation of error-messages" POSITION="right"/>
<node TEXT="Fulltext search" POSITION="left"/>
<node TEXT="Make MySQLServer::connection not accessible (remove getConnection() method),  see databaseWizard.ui.h" POSITION="left"/>
<node COLOR="#000000" TEXT="http://en.opensuse.org/Build_Service_Team&#xa;http://build.opensuse.org/" POSITION="left"/>
<node TEXT="Verbessertes Design:&#xa;Server s( ... ); Database d( s, ... ); Statement x( d, ... ); Statement x( s, ... ); ResultRow r( x );&#xa;How to create/destroy database?&#xa;How to have abstraction in XSU, which is calling Statement?&#xa;" POSITION="left"/>
<node COLOR="#ff0000" TEXT="RecipeML import from single files and directories,&#xa;Import during creation of database!&#xa;Check reimport&#xa;Examples for quantity:&#xa; *&lt;qty&gt;3&lt;frac&gt;&lt;n&gt;1&lt;/n&gt;&lt;d&gt;2&lt;/d&gt;&lt;/frac&gt;&lt;/qty&gt;&#xa; *&lt;range&gt;&lt;q1&gt;3&lt;/q1&gt;&lt;sep&gt;-&lt;/sep&gt;&lt;q2&gt;4&lt;/q2&gt;&lt;/range&gt;&#xa; *&lt;qty&gt;&quot;Some&lt;/qty&gt;" POSITION="left">
<node TEXT="RecipeML export to multiple files">
<node TEXT="Additional database entries:&#xa;* photo(s)&#xa;* author&#xa;* difficulty&#xa;* notes&#xa;* preparation time" FOLDED="true">
<node TEXT="Improved layout"/>
<node TEXT="Export to Wikipedia Cookbook format"/>
</node>
<node TEXT="export to latex (using latex-ucs), openoffice, rtf"/>
</node>
</node>
<node TEXT="Documentation:&#xa;for i in `seq -w 1 110`;&#xa;do wget http://dsquirrel.tripod.com/xmlzips/RecipeMLArchive00$i.zip;&#xa;done" POSITION="left"/>
<node TEXT="Mealmaster-documentation" POSITION="right"/>
</node>
</map>

==> anymeal_0.30.orig.tar.gz: anymeal-0.30/anymeal.mm <==
<map version="0.7.1">
<node TEXT="anymeal">
<node COLOR="#bfbfbf" TEXT="backup/restore for database" POSITION="left"/>
<node TEXT="Axis C++ Server/XQuery" FOLDED="true" POSITION="right">
<node TEXT="XSD for protocol (wrapping of anymeal.xsd?)"/>
</node>
<node TEXT="Reconnect button (problem with temporary table)" POSITION="right"/>
<node COLOR="#ff0000" TEXT="* Umstellung auf Qt4&#xa;* Closed-source release ohne KDE, Nsis, Windows port&#xa;" POSITION="right">
<node TEXT="KDE IO-slave, fuser-filesystem">
<node TEXT="Import from web-pages:&#xa;epicurious, allrecipes.com, and recipezaar.com"/>
<node TEXT="RecipeML import from archives"/>
<node TEXT="Import von Newsgruppen"/>
</node>
<node TEXT="Multiple selections">
<node TEXT="Provide &quot;Last Imported&quot; as selection (comp. Refworks),&#xa;Zeige Zahl der importierten Rezepte an">
<node TEXT="provide statistic on selections"/>
</node>
<node TEXT="expert mode for performing searches">
<node TEXT="Speed up search. Distinguish&#xa;* regular expression/word&#xa;* substring&#xa;* fulltext/word&#xa;Allow clear search"/>
</node>
</node>
<node TEXT="Vorw&#xe4;rts-/R&#xfc;ckw&#xe4;rts-Button"/>
<node TEXT="Smart shopping list planner"/>
<node TEXT="online context help"/>
<node TEXT="display recipe-ID in editor caption"/>
<node TEXT="faster recipe display/browsing through recipes"/>
<node TEXT="Editing copy of recipe"/>
<node COLOR="#ff0000" TEXT="Verification of editor"/>
<node TEXT="colourful user-interface"/>
<node TEXT="sort by most frequently used, rating for recipes"/>
<node TEXT="combining search queries (f.e. category &quot;Indian&quot; and &quot;Dessert&quot;)"/>
<node TEXT="direct printing out of recipes"/>
<node TEXT="sort recipes by category or title"/>
<node COLOR="#bfbfbf" TEXT="KDE clipboard"/>
</node>
<node TEXT="MySQL &lt;-&gt; XML http://dev.mysql.com/tech-resources/articles/mysql-5.1-xml.html&#xa;http://en.wikipedia.org/wiki/MySQL&#xa;http://en.wikipedia.org/wiki/PostgreSQL" POSITION="right"/>
<node TEXT="Add filename information to mealmaster-error (both for abort on error and export erroneous files), when importing" POSITION="right"/>
<node TEXT="Allow exporting not only with context-menu." POSITION="right"/>
<node TEXT="Internationalisation of error-messages" POSITION="right"/>
<node TEXT="Fulltext search" POSITION="left"/>
<node TEXT="Make MySQLServer::connection not accessible (remove getConnection() method),  see databaseWizard.ui.h" POSITION="left"/>
<node COLOR="#000000" TEXT="http://en.opensuse.org/Build_Service_Team&#xa;http://build.opensuse.org/" POSITION="left"/>
<node TEXT="Verbessertes Design:&#xa;Server s( ... ); Database d( s, ... ); Statement x( d, ... ); Statement x( s, ... ); ResultRow r( x );&#xa;How to create/destroy database?&#xa;How to have abstraction in XSU, which is calling Statement?&#xa;" POSITION="left"/>
<node COLOR="#ff0000" TEXT="RecipeML import from single files and directories,&#xa;Import during creation of database!&#xa;Check reimport&#xa;Examples for quantity:&#xa; *&lt;qty&gt;3&lt;frac&gt;&lt;n&gt;1&lt;/n&gt;&lt;d&gt;2&lt;/d&gt;&lt;/frac&gt;&lt;/qty&gt;&#xa; *&lt;range&gt;&lt;q1&gt;3&lt;/q1&gt;&lt;sep&gt;-&lt;/sep&gt;&lt;q2&gt;4&lt;/q2&gt;&lt;/range&gt;&#xa; *&lt;qty&gt;&quot;Some&lt;/qty&gt;" POSITION="left">
<node TEXT="RecipeML export to multiple files">
<node TEXT="Additional database entries:&#xa;* photo(s)&#xa;* author&#xa;* difficulty&#xa;* notes&#xa;* preparation time" FOLDED="true">
<node TEXT="Improved layout"/>
<node TEXT="Export to Wikipedia Cookbook format"/>
</node>
<node TEXT="export to latex (using latex-ucs), openoffice, rtf"/>
</node>
</node>
<node TEXT="Documentation:&#xa;for i in `seq -w 1 110`;&#xa;do wget http://dsquirrel.tripod.com/xmlzips/RecipeMLArchive00$i.zip;&#xa;done" POSITION="left"/>
<node TEXT="Mealmaster-documentation" POSITION="right"/>
</node>
</map>
